##  Adding Relations in Bulk Using Filters
Instead of selecting fact sheets one by one, you can use filters to select and add multiple fact sheets when establishing relations quickly.
  1. Hover over the section where you want to add relations to other fact sheets.
  2. From the three-dot menu at the right, select Add with Filters.
  3. In the filter overlay that appears, use the available filters and smart search functionality to find and select fact sheets.
  4. Click Use Selected Fact Sheets.
  5. Fill in the ‘fields on relation’ as needed for all the selected fact sheets simultaneously.
  6. Click Save or use the Save & Next button to move automatically to the next section.
